==> qmmp-1.2.3.tar.bz2: qmmp-1.2.3/src/plugins/Effect/crossfade/translations/crossfade_plugin_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>EffectCrossfadeFactory</name>
    <message>
        <location filename="../effectcrossfadefactory.cpp" line="31"/>
        <source>Crossfade Plugin</source>
        <translation>Estensione dissolvenza incrociata</translation>
    </message>
    <message>
        <location filename="../effectcrossfadefactory.cpp" line="52"/>
        <source>About Crossfade Plugin</source>
        <translation>Informazioni sull&apos;estensione dissolvenza incrociata</translation>
    </message>
    <message>
        <location filename="../effectcrossfadefactory.cpp" line="53"/>
        <source>Qmmp Crossfade Plugin</source>
        <translation>Estensione dissolvenza incrociata per Qmmp</translation>
    </message>
    <message>
        <location filename="../effectcrossfadefactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Autori: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Crossfade Plugin Settings</source>
        <translation>Impostazioni estensione dissolvenza incrociata</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Overlap:</source>
        <translation>Sovrapposizione:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
</context>
</TS>

==> qmmp-2.2.6.tar.bz2: qmmp-2.2.6/src/plugins/Effect/crossfade/translations/crossfade_plugin_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>CrossfadeSettingsDialog</name>
    <message>
        <location filename="../crossfadesettingsdialog.ui" line="14"/>
        <source>Crossfade Plugin Settings</source>
        <translation>Impostazioni estensione dissolvenza incrociata</translation>
    </message>
    <message>
        <location filename="../crossfadesettingsdialog.ui" line="29"/>
        <source>Overlap:</source>
        <translation>Sovrapposizione:</translation>
    </message>
    <message>
        <location filename="../crossfadesettingsdialog.ui" line="42"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
</context>
<context>
    <name>EffectCrossfadeFactory</name>
    <message>
        <location filename="../effectcrossfadefactory.cpp" line="30"/>
        <source>Crossfade Plugin</source>
        <translation>Estensione dissolvenza incrociata</translation>
    </message>
    <message>
        <location filename="../effectcrossfadefactory.cpp" line="50"/>
        <source>About Crossfade Plugin</source>
        <translation>Informazioni sull&apos;estensione dissolvenza incrociata</translation>
    </message>
    <message>
        <location filename="../effectcrossfadefactory.cpp" line="51"/>
        <source>Qmmp Crossfade Plugin</source>
        <translation>Estensione dissolvenza incrociata per Qmmp</translation>
    </message>
    <message>
        <location filename="../effectcrossfadefactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Autori: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
</TS>
